| Title: | Neutrosophic Analysis Crossover Designs |
| Version: | 0.0.1 |
| Maintainer: | Vinaykumar L.N. <vinaymandya123@gmail.com> |
| Description: | Provides methods for Neutrosophic Analysis of Variance (NANOVA) for crossover designs and multi-session designs with direct and residual effects using interval-valued observations. The package computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and multiple comparisons using Least Significant Difference (LSD) procedures. For crisp data, users may enter identical lower and upper response values to obtain classical Analysis of Variance (ANOVA) results. The basic idea of neutrosophic statistics is obtained from Smarandache (2014) https://fs.unm.edu/NeutrosophicStatistics.pdf, while the analysis procedures implemented in this package are newly developed. |
| License: | GPL-2 | GPL-3 [expanded from: GPL (≥ 2)] |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Imports: | MASS |
| NeedsCompilation: | no |
| Packaged: | 2026-06-04 04:38:07 UTC; admin |
| Author: | Neethu R.S [aut, ctb], Boyina Devi Priyanka [aut, ctb], Cini Varghese [aut, ctb], Mohd Harun [aut, ctb], Anindita Datta [aut, ctb], Vinaykumar L.N. [aut, cre] |
| Repository: | CRAN |
| Date/Publication: | 2026-06-09 07:20:16 UTC |
Neutrosophic Analysis of Crossover Designs
Description
Performs Neutrosophic Analysis of Variance (NANOVA) for crossover designs using interval-valued observations. The function computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and Least Significant Difference (LSD)-based multiple comparisons for direct and residual effects.
Usage
CODnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = TRUE)
Arguments
Lower_y |
Matrix containing lower bounds of observations. |
Upper_y |
Matrix containing upper bounds of observations. |
design |
Matrix representing treatment allocation in crossover or multi-session designs. |
alpha |
Significance level for F-tests and LSD comparisons. Default is 0.05. |
verbose |
Logical. If TRUE, ANOVA tables, LSD comparisons and explanatory messages are displayed. Default is TRUE. |
Details
Input matrix structure:
Rows represent periods or sessions.
Columns represent panelists or experimental units.
'Lower_y' and 'Upper_y' must have the same dimensions as the design matrix.
The design should correspond to a balanced crossover or multi-session structure.
The function performs neutrosophic analysis for:
Direct effects adjusted for residual effects.
Residual effects adjusted for direct effects.
Direct effects ignoring residual effects.
Residual effects ignoring direct effects.
Value
A list containing neutrosophic ANOVA tables, test statistics and LSD comparison results. When verbose = TRUE, the results are also printed to the console.
Examples
Lower_y <- matrix(c(
14.38454,6.222194,12.27037,7.061317,7.537346,
13.31869,5.9473,11.2351,6.585916,4.586305,
5.685368,16.28068,9.835431,2.647609,7.034929,
4.940916,4.853256,17.17372,9.880024,13.25461,
13.5076,9.957738,8.674778,16.90606,11.25864,
6.802249,6.980052,14.30639,8.701582,12.41051,
6.13914,15.89982,7.98234,6.391511,7.960419,
7.693432,12.3215,8.131515,17.56524,7.158118,
16.25562,7.500688,11.55641,6.065295,7.336593
), nrow = 9, byrow = TRUE)
Upper_y <- matrix(c(
16.99546,15.25781,16.12963,11.21868,10.72265,
18.06131,15.5327,17.1649,11.69408,13.6737,
10.53463,26.25932,11.84457,12.57239,15.74507,
11.01908,11.22674,20.92628,13.15998,17.86539,
18.4324,15.80226,13.68522,19.01394,15.32136,
12.87775,9.359948,23.05361,17.15842,19.80949,
8.46086,23.94018,15.69766,9.528489,16.97958,
14.34657,17.1185,11.28849,23.69476,9.601882,
18.84438,14.35931,17.74359,11.9947,12.00341
), nrow = 9, byrow = TRUE)
design <- matrix(c(
1,2,3,4,5,
5,1,2,3,4,
2,3,4,5,1,
4,5,1,2,3,
3,4,5,1,2,
4,5,1,2,3,
2,3,4,5,1,
5,1,2,3,4,
1,2,3,4,5
), nrow = 9, byrow = TRUE)
CODnsANOVA(Lower_y, Upper_y, design, alpha = 0.05,verbose = TRUE)
Neutrosophic Analysis of Multi-Session Designs
Description
Performs Neutrosophic Analysis of Variance (NANOVA) for multi-session designs using interval-valued observations. The function computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and Least Significant Difference (LSD)-based multiple comparisons for direct effects.
Usage
MSDnsANOVA(design, Lower_y, Upper_y, alpha = 0.05, verbose = TRUE)
Arguments
design |
Matrix representing treatment allocation in the multi-session design. |
Lower_y |
Matrix containing lower bounds of observations. |
Upper_y |
Matrix containing upper bounds of observations. |
alpha |
Significance level for F-tests and LSD comparisons. Default is 0.05. |
verbose |
Logical. If TRUE, ANOVA tables, LSD comparisons and explanatory messages are displayed. If FALSE, results are returned without console output. Default is TRUE. |
Details
Input matrix structure:
Rows represent sessions or periods.
Columns represent panelists or experimental units.
'Lower_y' and 'Upper_y' must have the same dimensions as the design matrix.
The design should correspond to a balanced multi-session structure.
Value
A list containing neutrosophic ANOVA tables, test statistics, p-values, treatment means, and LSD comparison results. When
verbose = TRUE, the results are also displayed in the console.
Examples
Lower_y <- matrix(c(
59.15397,60.36055,62.80413,62.04122,65.8956,68.0182,67.44426,71.08241,
60.89585,56.19409,60.90852,67.56094,66.22519,65.20828,69.30839,70.31622,
63.46957,63.34746,66.00188,67.67013,71.0481,72.71216,74.19682,58.53621,
58.84885,65.96608,64.17269,64.76445,62.51671,67.6455,64.32132,70.29533,
62.86118,64.47177,68.33016,71.65421,72.48458,75.36005,61.32384,61.59534,
62.78424,59.8565,60.66082,64.33951,67.01462,74.53668,71.43119,65.60705,
65.17206,70.08045,72.38313,71.72911,74.56296,61.09245,62.45687,64.43367,
66.48764,63.57168,67.44713,63.3231,63.49549,69.50216,62.90725,70.11032
), nrow = 8, byrow = TRUE)
Upper_y <- matrix(c(
63.96603,66.39945,67.59587,71.95878,71.7044,73.0818,77.23574,77.53759,
64.74415,65.68591,69.61148,72.81906,69.97481,74.25172,73.89161,76.08378,
66.33043,70.25254,71.19812,73.32987,73.5519,75.48784,77.60318,68.46379,
68.61115,69.07392,66.48731,73.63555,71.68329,73.9545,73.47868,74.90467,
71.53882,73.72823,73.66984,73.94579,76.91542,77.63995,66.87616,70.20466,
69.21576,68.9435,69.33918,67.26049,72.98538,79.46332,78.56881,70.99295,
74.42794,73.31955,74.61687,79.07089,79.83704,68.90755,71.14313,72.76633,
70.71236,70.22832,76.95287,72.6769,68.50451,76.49784,68.69275,72.48968
), nrow = 8, byrow = TRUE)
design <- matrix(c(
1,2,3,4,5,6,7,8,
8,1,2,3,4,5,6,7,
2,3,4,5,6,7,8,1,
7,8,1,2,3,4,5,6,
3,4,5,6,7,8,1,2,
6,7,8,1,2,3,4,5,
4,5,6,7,8,1,2,3,
5,6,7,8,1,2,3,4
), nrow = 8, byrow = TRUE)
MSDnsANOVA(design, Lower_y, Upper_y, alpha = 0.05, verbose = TRUE)