| Title: | Neutrosophic Analysis Crossover Designs |
| Version: | 0.2.0 |
| Maintainer: | Vinaykumar L.N. <vinaymandya123@gmail.com> |
| Description: | Provides methods for Neutrosophic Analysis of Variance (NANOVA) and Neutrosophic Analysis of Covariance (NANCOVA) for crossover designs, as well as NANOVA for multi-session designs with direct and residual effects using interval-valued observations. For crisp data, users can enter identical lower and upper values for the response and covariate variables to obtain results equivalent to classical Analysis of Variance (ANOVA) and Analysis of Covariance (ANCOVA), respectively. The basic concepts of neutrosophic statistics are based on Smarandache (2014) https://fs.unm.edu/NeutrosophicStatistics.pdf, while the analysis procedures implemented in this package are newly developed. |
| License: | GPL-2 | GPL-3 [expanded from: GPL (≥ 2)] |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Imports: | MASS |
| NeedsCompilation: | no |
| Packaged: | 2026-08-21 09:21:20 UTC; admin |
| Author: | Boyina Devi Priyanka [aut, ctb], Neethu R.S [aut, ctb], Cini Varghese [aut, ctb], Mohd Harun [aut, ctb], Anindita Datta [aut, ctb], Vinaykumar L.N. [aut, cre] |
| Repository: | CRAN |
| Date/Publication: | 2026-08-21 13:20:30 UTC |
Neutrosophic Analysis of Covariance for Crossover Designs
Description
Performs neutrosophic ANCOVA for crossover designs with direct treatment, residual, unit, period, and covariate effects. For crisp data, provide identical lower and upper matrices ('Lower_y = Upper_y' and 'Lower_z = Upper_z'); the function then yields classical ANCOVA results.
Usage
CODnsANCOVA(
Lower_y,
Upper_y,
Lower_z,
Upper_z,
design,
alpha = 0.05,
verbose = TRUE
)
Arguments
Lower_y |
Matrix of lower response values. |
Upper_y |
Matrix of upper response values. |
Lower_z |
Matrix of lower covariate values. |
Upper_z |
Matrix of upper covariate values. |
design |
Treatment-allocation matrix. |
alpha |
Significance level. Default is 0.05. |
verbose |
Logical; print the ANCOVA table when 'TRUE'. |
Value
A list containing the neutrosophic ANCOVA table and calculated sums of squares, mean sums of squares, and F statistics.
Examples
Lower_y <- matrix(c(
13.14, 9.40, 12.73, 6.72, 6.32,
7.00, 11.47, 5.78, 16.06, 4.69,
5.60, 20.22, 9.57, 5.00, 9.73,
5.53, 6.64, 17.39, 9.57, 14.54,
14.46, 9.99, 8.87, 15.12, 10.45,
7.88, 6.62, 15.98, 10.29, 14.20,
4.83, 18.34, 9.70, 5.00, 9.89,
10.01, 13.20, 8.36, 17.94, 5.50,
16.17, 9.40, 12.96, 6.34, 7.19
), nrow = 9, byrow = TRUE)
Upper_y <- matrix(c(
18.24, 12.08, 15.67, 11.56, 11.94,
12.38, 15.29, 11.10, 21.90, 9.99,
10.62, 22.32, 12.11, 10.22, 13.05,
10.43, 9.44, 20.71, 13.47, 16.58,
17.48, 15.77, 13.49, 20.80, 16.13,
11.80, 9.72, 21.38, 15.57, 18.02,
9.77, 21.50, 13.98, 10.92, 15.05,
12.03, 16.24, 11.06, 23.32, 11.26,
18.93, 12.46, 16.34, 11.72, 12.15
), nrow = 9, byrow = TRUE)
Lower_z <- matrix(c(
195.89, 96.89, 257.23, 261.07, 254.25,
145.95, 117.95, 387.43, 105.70, 215.71,
163.26, 248.84, 235.63, 307.45, 246.18,
130.16, 195.21, 285.14, 307.71, 209.24,
138.38, 260.36, 310.74, 249.52, 98.62,
151.72, 226.72, 257.21, 205.90, 196.29,
251.63, 225.61, 207.61, 217.33, 261.98,
37.32, 96.61, 287.98, 241.99, 307.31,
304.91, 306.46, 405.96, 348.47, 307.91
), nrow = 9, byrow = TRUE)
Upper_z <- matrix(c(
204.11, 103.11, 262.77, 264.93, 263.75,
154.05, 122.05, 392.57, 112.30, 220.29,
166.74, 251.16, 242.37, 310.55, 251.82,
133.84, 200.79, 292.86, 312.29, 218.76,
141.62, 267.64, 313.26, 254.48, 101.38,
160.28, 233.28, 264.79, 214.10, 203.71,
260.37, 234.39, 212.39, 226.67, 266.02,
46.68, 103.39, 292.02, 248.01, 312.69,
311.09, 313.54, 414.04, 351.53, 316.09
), nrow = 9, byrow = TRUE)
design <- matrix(c(
1, 2, 3, 4, 5,
5, 1, 2, 3, 4,
2, 3, 4, 5, 1,
4, 5, 1, 2, 3,
3, 4, 5, 1, 2,
4, 5, 1, 2, 3,
2, 3, 4, 5, 1,
5, 1, 2, 3, 4,
1, 2, 3, 4, 5
), nrow = 9, byrow = TRUE)
CODnsANCOVA(
Lower_y = Lower_y,
Upper_y = Upper_y,
Lower_z = Lower_z,
Upper_z = Upper_z,
design = design,
alpha = 0.05,
verbose = TRUE
)
Neutrosophic Analysis of Crossover Designs
Description
Performs neutrosophic analysis of variance for crossover designs with direct and residual effects using interval-valued observations.
Usage
CODnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = TRUE)
Arguments
Lower_y |
Matrix of lower response values. |
Upper_y |
Matrix of upper response values. |
design |
Treatment-allocation matrix. Rows represent periods and columns represent experimental units or panelists. |
alpha |
Significance level for F-tests and LSD comparisons. Default is 0.05. |
verbose |
Logical; print ANOVA tables and LSD comparisons when 'TRUE'. |
Details
For crisp data, provide identical lower and upper matrices ('Lower_y = Upper_y'); the function then yields classical ANOVA results.
Value
A list containing neutrosophic ANOVA tables, test statistics, treatment means, and LSD comparison results.
Examples
Lower_y <- matrix(c(
13.14, 9.40, 12.73, 6.72, 6.32, 18.24, 12.08, 15.67,
7.00, 11.47, 5.78, 16.06, 4.69, 12.38, 15.29, 11.10,
5.60, 20.22, 9.57, 5.00, 9.73, 10.62, 22.32, 12.11,
5.53, 6.64, 17.39, 9.57, 14.54, 10.43, 9.44, 20.71,
14.46, 9.99, 8.87, 15.12, 10.45, 17.48, 15.77, 13.49,
7.88, 6.62, 15.98, 10.29, 14.20, 11.80, 9.72, 21.38,
4.83, 18.34, 9.70, 5.00, 9.89, 9.77, 21.50, 13.98,
10.01, 13.20, 8.36, 17.94, 5.50, 12.03, 16.24, 11.06
), nrow = 8, byrow = TRUE)
Upper_y <- matrix(c(
18.24, 12.08, 15.67, 11.56, 11.94, 20.24, 16.08, 20.67,
12.38, 15.29, 11.10, 21.90, 9.99, 17.38, 20.29, 15.10,
10.62, 22.32, 12.11, 10.22, 13.05, 15.62, 27.32, 17.11,
10.43, 9.44, 20.71, 13.47, 16.58, 15.43, 14.44, 25.71,
17.48, 15.77, 13.49, 20.80, 16.13, 22.48, 20.77, 18.49,
11.80, 9.72, 21.38, 15.57, 18.02, 16.80, 14.72, 25.38,
9.77, 21.50, 13.98, 10.92, 15.05, 14.77, 26.50, 18.98,
12.03, 16.24, 11.06, 23.32, 11.26, 17.03, 21.24, 16.06
), nrow = 8, byrow = TRUE)
design <- matrix(c(
1,2,3,4,5,6,7,8,
8,1,2,3,4,5,6,7,
2,3,4,5,6,7,8,1,
7,8,1,2,3,4,5,6,
3,4,5,6,7,8,1,2,
6,7,8,1,2,3,4,5,
4,5,6,7,8,1,2,3,
5,6,7,8,1,2,3,4
), nrow = 8, byrow = TRUE)
CODnsANOVA(Lower_y, Upper_y, design, alpha=0.05,verbose = TRUE)
Neutrosophic Analysis of Multi-Session Designs
Description
Performs determinate–indeterminate neutrosophic ANOVA for the revised two-session crossover design methodology.
Usage
MSDnsANOVA(design, D, I, verbose = TRUE)
Arguments
design |
Square treatment-allocation matrix. Rows are periods and columns are panelists. |
D |
Matrix of determinate observations, with the same dimensions as 'design'. |
I |
Matrix of indeterminate observations, with the same dimensions as 'design'. |
verbose |
Logical; print the ANOVA table when 'TRUE'. |
Details
For crisp data, provide an indeterminate matrix containing only zeros ('I = 0'); the function then yields classical ANOVA results.
Value
A list containing the ANOVA table, information matrices, canonical efficiency factors, sums of squares, mean square error, and degrees of freedom.
Examples
design <- matrix(c(
1,2,3,4,5,6,7,8,
8,1,2,3,4,5,6,7,
2,3,4,5,6,7,8,1,
7,8,1,2,3,4,5,6,
3,4,5,6,7,8,1,2,
6,7,8,1,2,3,4,5,
4,5,6,7,8,1,2,3,
5,6,7,8,1,2,3,4
), nrow = 8, byrow = TRUE)
D <- matrix(c(
61.56,63.38,65.20,67.00,68.80,70.55,71.20,70.11,
62.82,60.94,65.26,69.234,68.10,68.21,71.60,73.20,
72.10,67.21,68.60,70.50,72.30,74.10,75.90,63.50,
66.21,67.52,68.90,69.20,67.10,70.80,68.90,72.60,
65.76,62.10,72.00,72.80,73.20,76.50,64.10,65.90,
65.20,64.40,65.00,65.80,71.00,73.26,71.65,68.30,
68.10,72.30,74.10,74.20,76.20,65.00,66.80,68.60,
68.60,66.90,72.20,68.00,66.00,73.00,65.80,71.30
), nrow = 8, byrow = TRUE)
I <- matrix(c(
2.41,3.02,2.40,4.96,2.90,2.53,4.90,3.23,
1.92,4.75,4.35,2.63,1.87,4.52,2.29,2.88,
1.43,3.45,2.60,2.83,1.25,1.39,1.70,4.96,
4.88,1.55,1.16,4.44,4.58,3.15,4.58,2.30,
4.34,4.63,2.67,1.15,2.22,1.14,2.78,4.30,
3.22,4.54,4.34,1.46,2.99,2.46,3.57,2.69,
4.63,1.62,1.12,3.67,2.64,3.91,4.34,4.17,
2.11,3.33,4.75,4.68,2.50,3.50,2.89,1.19
), nrow = 8, byrow = TRUE)
result <- MSDnsANOVA(design, D, I, verbose = TRUE)